@@ -382,7 +382,7 @@ Pvm_CreateEventHandler(tid, msgtag, proc, clientData)
 	    break;
 	}
     }
-    if (pvmPtr == NULL||pvmPtr->tid!=tid||pvmPtr->msgtag!=msgtag) {
+    if ((pvmPtr == NULL)||(pvmPtr->tid!=tid)||(pvmPtr->msgtag!=msgtag)) {
 	Ptr = (pvmHandler *) ckalloc(sizeof(pvmHandler));
 	Ptr->tid = tid;
 	Ptr->msgtag = msgtag;
@@ -476,10 +476,6 @@ Pvm_DeleteEventHandler(tid, msgtag)
  *----------------------------------------------------------------------
  */
 
-#ifndef TCL_ACTIVE
-#define TCL_ACTIVE (1<<4)
-#endif
-
 static void
 PvmHandlerSetupProc(clientData, flags)
     ClientData clientData;		/* Not used. */
@@ -490,6 +486,9 @@ PvmHandlerSetupProc(clientData, flags)
 
     if (firstPvmHandlerPtr == NULL) return;
 
+#ifdef TCL_ACTIVE
+    Tcl_WatchFile((Tcl_File) NULL, TCL_ACTIVE);
+#endif
     /*
      * register File handler for all fd's in use for pvm, such
      * that it will be executed when a PVM-package is received.
@@ -498,7 +497,7 @@ PvmHandlerSetupProc(clientData, flags)
     n = pvm_getfds(&fdlist);
     for(i=0; i<n;i++) {
 	Tcl_WatchFile(Tcl_GetFile((ClientData)fdlist[i],TCL_UNIX_FD),
-		TCL_READABLE|TCL_EXCEPTION|TCL_ACTIVE);
+		TCL_READABLE|TCL_EXCEPTION);
     }
     blockTime.sec = 0;
     blockTime.usec = 100000;
@@ -605,7 +604,7 @@ PvmHandlerEventProc(evPtr, flags)
 
     pvm_setrbuf(buffer);
     pvm_bufinfo(buffer,&number,&msgtag,&tid);
-    if (tid==0x80000000) {
+    if (tid & 0x80000000) {
 	switch(msgtag) {
 	case KILLTID_MSGTAG:
 	    info = pvm_upkint(&tid,1,1);
