@@ -20,6 +20,7 @@ int (*tclDummyMathPtr) _ANSI_ARGS_((int exception)) = matherr;
 
 
 extern int	Pvm_Init _ANSI_ARGS_((Tcl_Interp *interp));
+extern int	Pvm_SafeInit _ANSI_ARGS_((Tcl_Interp *interp));
 extern void	Pvm_Main _ANSI_ARGS_((int argc, char **argv,
 			    Tcl_AppInitProc *appInitProc));
 
@@ -102,7 +103,7 @@ Tcl_AppInit(interp)
 	return TCL_ERROR;
     }
 #if (TCL_MAJOR_VERSION > 7) || (TCL_MINOR_VERSION > 4)
-    Tcl_StaticPackage(interp, "Pvm", Pvm_Init, (Tcl_PackageInitProc *) NULL);
+    Tcl_StaticPackage(interp, "Pvm", Pvm_Init, Pvm_SafeInit);
 #endif
 
     /*
@@ -112,10 +113,10 @@ Tcl_AppInit(interp)
      * then no user-specific startup file will be run under any conditions.
      */
 
-#if (TCL_MAJOR_VERSION == 7) && (TCL_MINOR_VERSION < 5)
-    tcl_RcFileName = "~/.pvmshrc";
-#else
+#if (TCL_MAJOR_VERSION > 7) || (TCL_MINOR_VERSION > 4)
     Tcl_SetVar(interp, "tcl_rcFileName", "~/.pvmshrc", TCL_GLOBAL_ONLY);
+#else
+    tcl_RcFileName = "~/.pvmshrc";
 #endif
     return TCL_OK;
 }
